@@ -3,7 +3,7 @@ package Wiki::Toolkit;
 use strict;
 
 use vars qw( $VERSION );
-$VERSION = '0.72';
+$VERSION = '0.74';
 
 use Carp qw(croak carp);
 use Digest::MD5 "md5_hex";
@@ -258,7 +258,7 @@ until they're tagged as moderated, when they will become the new node.
 
 sub set_node_moderation {
     my ($self, @args) = @_;
-    $self->store->set_node_moderation( @args );
+    return $self->store->set_node_moderation( @args );
 }
 
 =item B<rename_node>
@@ -571,6 +571,22 @@ sub list_node_all_versions {
     return $self->store->list_node_all_versions(%args);
 }
 
+=item B<list_last_version_before>
+	List the last version of every node before a given date.
+	If no version existed before that date, will return undef for version.
+	Returns a hash of id, name, version and date
+
+	my @nv = $wiki->list_last_version_before('2007-01-02 10:34:11')
+	foreach my $data (@nv) {
+		
+	}
+=cut
+sub list_last_version_before {
+    my ($self,@argsarray) = @_;
+
+    return $self->store->list_last_version_before(@argsarray);
+}
+
 =item B<node_exists>
 
   my $ok = $wiki->node_exists( "Wombat Defenestration" );
@@ -786,6 +802,7 @@ sub register_plugin {
     my $plugin = $args{plugin} || "";
     croak "no plugin supplied" unless $plugin;
     if ( $plugin->isa( "Wiki::Toolkit::Plugin" ) ) {
+        $plugin->wiki(      $self             );
         $plugin->datastore( $self->store      );
         $plugin->indexer(   $self->search_obj );
         $plugin->formatter( $self->formatter  );
